@@ -1,3 +1,4 @@
+import threading
 from pglet.protocol import Command
 from difflib import SequenceMatcher
 import datetime as dt
@@ -20,6 +21,7 @@ class Control:
         self.disabled = disabled
         self.data = data
         self.__event_handlers = {}
+        self._lock = threading.Lock()
 
     def _get_children(self):
         return []
@@ -167,10 +169,11 @@ class Control:
         self.__page.update(self)
 
     def clean(self):
-        self._previous_children.clear()
-        for child in self._get_children():
-            self._remove_control_recursively(self.__page.index, child)
-        return self.__page._send_command("clean", [self.uid])
+        with self._lock:
+            self._previous_children.clear()
+            for child in self._get_children():
+                self._remove_control_recursively(self.__page.index, child)
+            return self.__page._send_command("clean", [self.uid])
 
     def build_update_commands(self, index, added_controls, commands):
         update_cmd = self._get_cmd_attrs(update=True)
