@@ -1,4 +1,4 @@
-from .control import Control
+from pglet.control import Control
 
 class Html(Control):
     def __init__(self, value=None, id=None, visible=None):
