@@ -1,4 +1,4 @@
-from .control import Control
+from pglet.control import Control
 
 class IFrame(Control):
     def __init__(self, name=None, id=None, src=None, border=None, title=None,
