@@ -1,6 +1,6 @@
 import logging
 import os
-import platform
+from pathlib import Path
 import subprocess
 import traceback
 from threading import Thread
@@ -8,23 +8,23 @@ import threading
 import traceback
 import signal
 from time import sleep
-from urllib.parse import urlparse, urlunparse
+import urllib.request
+import tempfile
+import zipfile
+import tarfile
 
-from .reconnecting_websocket import ReconnectingWebSocket
-from .utils import is_localhost_url, which
-from .connection import Connection
-from .page import Page
-from .event import Event
-from .constants import *
-
-HOSTED_SERVICE_URL = "https://app.pglet.io"
-CONNECT_TIMEOUT_SECONDS = 30
+from pglet.reconnecting_websocket import ReconnectingWebSocket
+from pglet.utils import *
+from pglet.connection import Connection
+from pglet.page import Page
+from pglet.event import Event
+from pglet import constants
 
 def page(name=None, local=False,  web=False, server=None, token=None, permissions=None, no_window=False):
     conn = _connect_internal(name, False, web, server, token, permissions, no_window)
     print("Page URL:", conn.page_url)
-    page = Page(conn, ZERO_SESSION)
-    conn.sessions[ZERO_SESSION] = page
+    page = Page(conn, constants.ZERO_SESSION)
+    conn.sessions[constants.ZERO_SESSION] = page
     return page
 
 def app(name=None, local=False, web=False, server=None, token=None, target=None, permissions=None, no_window=False):
@@ -47,7 +47,7 @@ def app(name=None, local=False, web=False, server=None, token=None, target=None,
     try:
         print("Connected to Pglet app and handling user sessions...")
 
-        if _is_windows():
+        if is_windows():
             input()
         else:
             terminate.wait()
@@ -58,10 +58,10 @@ def app(name=None, local=False, web=False, server=None, token=None, target=None,
 
 def _connect_internal(name=None, is_app=False, web=False, server=None, token=None, permissions=None, no_window=False, session_handler=None):
     if server == None and web:
-        server = HOSTED_SERVICE_URL
+        server = constants.HOSTED_SERVICE_URL
     elif server == None:
         env_port = os.getenv('PGLET_SERVER_PORT')
-        port = env_port if env_port != None and env_port != "" else "5000"
+        port = env_port if env_port != None and env_port != "" else constants.PGLET_SERVER_DEFAULT_PORT
         server = f"http://localhost:{port}"
 
     connected = threading.Event()
@@ -99,7 +99,7 @@ def _connect_internal(name=None, is_app=False, web=False, server=None, token=Non
         conn.page_name = result.pageName
         conn.page_url = f"{server.rstrip('/')}/{result.pageName}"
         if not no_window and not conn.browser_opened:
-            _open_browser(conn.page_url)
+            open_in_browser(conn.page_url)
             conn.browser_opened = True
         connected.set()
 
@@ -111,53 +111,36 @@ def _connect_internal(name=None, is_app=False, web=False, server=None, token=Non
     ws.on_connect = _on_ws_connect
     ws.on_failed_connect = _on_ws_failed_connect
     ws.connect()
-    for n in range(0, CONNECT_TIMEOUT_SECONDS):
+    for n in range(0, constants.CONNECT_TIMEOUT_SECONDS):
         if not connected.is_set():
             sleep(1)
     if not connected.is_set():
         ws.close()
-        raise Exception(f"Could not connected to Pglet server in {CONNECT_TIMEOUT_SECONDS} seconds.")
+        raise Exception(f"Could not connected to Pglet server in {constants.CONNECT_TIMEOUT_SECONDS} seconds.")
 
     return conn
 
 def _start_pglet_server():
     print("Starting Pglet Server in local mode...")
 
-    if _is_windows():
-        pglet_exe = "pglet.exe"
+    pglet_exe = "pglet.exe" if is_windows() else "pglet"
+
+    # check if pglet.exe exists in "bin" directory (user mode)
+    p = Path(__file__).parent.joinpath("bin", f"{get_platform()}-{get_arch()}", pglet_exe)
+    if p.exists():
+        pglet_path = str(p)
+        logging.info(f"Pglet Server found in: {pglet_path}")
     else:
-        pglet_exe = "pglet"
-
-    # check if pglet.exe is in PATH already (development mode)
-    pglet_in_path = which(pglet_exe)
-    if pglet_in_path:
-        pglet_exe = pglet_in_path
-    else:
-        bin_dir = os.path.join(os.path.dirname(__file__), "bin")
-
-        p = platform.system()
-        if _is_windows():
-            plat = "windows"
-        elif p == "Linux":
-            plat = "linux"
-        elif p == "Darwin":
-            plat = "darwin"
+        # check if pglet.exe is in PATH (pglet developer mode)
+        pglet_path = which(pglet_exe)
+        if not pglet_path:
+            # download pglet from GitHub (python module developer mode)
+            pglet_path = _download_pglet()
         else:
-            raise Exception(f"Unsupported platform: {p}")
+            logging.info(f"Pglet Server found in PATH")
 
-        a = platform.machine().lower()
-        if a == "x86_64" or a == "amd64":
-            arch = "amd64"
-        elif a == "arm64" or a == "aarch64":
-            arch = "arm64"
-        elif a.startswith("arm"):
-            arch = "arm"
-        else:
-            raise Exception(f"Unsupported architecture: {a}")
-
-        pglet_exe = os.path.join(bin_dir, f"{plat}-{arch}", pglet_exe)
-
-    args = [pglet_exe, "server", "--background"]
+    # start Pglet server
+    args = [pglet_path, "server", "--background"]
 
     # auto-detect Replit environment
     if os.getenv("REPL_ID") != None:
@@ -165,12 +148,6 @@ def _start_pglet_server():
 
     subprocess.run(args, check=True)
 
-def _open_browser(url):
-    if _is_windows():
-        subprocess.run(["explorer.exe", url])
-    elif _is_macos():
-        subprocess.run(["open", url])
-
 def _get_ws_url(server: str):
     url = server.rstrip('/')
     if server.startswith('https://'):
@@ -181,11 +158,49 @@ def _get_ws_url(server: str):
         url = 'ws://' + url
     return url + "/ws"
 
-def _is_windows():
-    return platform.system() == "Windows"
+def _download_pglet():
+    pglet_exe = "pglet.exe" if is_windows() else "pglet"
+    pglet_bin = Path.home().joinpath(".pglet", "bin")
+    pglet_bin.mkdir(parents=True, exist_ok=True)
 
-def _is_macos():
-    return platform.system() == "Darwin"  
+    pglet_version = _get_pglet_version()
+    
+    installed_ver = None
+    pglet_path = pglet_bin.joinpath(pglet_exe)
+    if pglet_path.exists():
+        # check installed version
+        installed_ver = subprocess.check_output([str(pglet_path), "--version"]).decode("utf-8")
+        logging.info(f"Pglet v{pglet_version} is already installed in {pglet_path}")
+    
+    if not installed_ver or installed_ver != pglet_version:
+        print(f"Downloading Pglet v{pglet_version} to {pglet_path}")
+
+        ext = "zip" if is_windows() else "tar.gz"
+        file_name = F"pglet-{pglet_version}-{get_platform()}-{get_arch()}.{ext}"
+        pglet_url = f"https://github.com/pglet/pglet/releases/download/v{pglet_version}/{file_name}"
+
+        temp_arch = Path(tempfile.gettempdir()).joinpath(file_name)
+        try:
+            urllib.request.urlretrieve(pglet_url, temp_arch)
+            if is_windows():
+                with zipfile.ZipFile(temp_arch, 'r') as zip_arch:
+                    zip_arch.extractall(pglet_bin)
+            else:
+                with tarfile.open(temp_arch, 'r:gz') as tar_arch:
+                    tar_arch.extractall(pglet_bin)            
+        finally:
+            os.remove(temp_arch)
+    return str(pglet_path)
+
+def _get_pglet_version():
+    appveyor_yml = Path(__file__).parent.parent.joinpath('appveyor.yml').absolute()
+
+    version_prefix = "PGLET_VERSION:"
+    with open(appveyor_yml) as yml:
+        for line in yml:
+            if version_prefix in line:
+                return line.split(':')[1].strip()
+    raise f"{version_prefix} not found in appveyor.yml"
 
 # Fix: https://bugs.python.org/issue35935
 # if _is_windows():
